@@ -7,8 +7,8 @@ use strict;
 use LWP::UserAgent;
 use HTTP::Request::Common;
 use CaCORE::ApplicationService;
-use CaCORE::CaBIO::CaBIO;
-use CaCORE::CaDSR::CaDSR;
+use CaCORE::CaBIO;
+use CaCORE::CaDSR;
 
 #
 # ApplicationService is a utility classs that encapsulates webservice invocation to caCORE server.
@@ -17,7 +17,8 @@ use CaCORE::CaDSR::CaDSR;
 # The URL being passed to the intance method is the service endpoint of the caCORE webservice.
 # If no such URL is provided in the program, it will default to the caCORE production server, "http://cabio.nci.nih.gov/cacore30/ws/caCOREService"
 #
-my $appsvc = CaCORE::ApplicationService->instance("http://cabio.nci.nih.gov/cacore30/ws/caCOREService");
+#my $appsvc = CaCORE::ApplicationService->instance("http://cbioqa101.nci.nih.gov:49080/cacore31/ws/caCOREService"); # qa
+my $appsvc = CaCORE::ApplicationService->instance("http://cabio.nci.nih.gov/cacore31/ws/caCOREService");
 
 # test CaBIO 1: use ApplicationService
 # 
@@ -88,7 +89,9 @@ eval{
 };
 warn "Test CaBIO 3 failed. Error:\n" . $@ if $@;
 foreach my $gn (@genes) {
-	print "Gene: id= " . $gn->getId . "  symbol=" . $gn->getSymbol . "\n";
+	print "Gene: id= " . $gn->getId;
+	if( defined($gn->getSymbol) ) { print "  symbol=" . $gn->getSymbol . "\n"; }
+	else { print "\n"; }
 }
 my $num = $#genes + 1;
 print "number of result: " . $num . "\n";
@@ -142,7 +145,9 @@ eval{
 };
 warn "Test CaBIO 5 failed. Error:\n" . $@ if $@;
 foreach my $gne (@geneSet) {
-	print "Gene: id= " . $gne->getId . "  symbol=" . $gne->getSymbol . "\n";
+	print "Gene: id= " . $gne->getId;
+	if( defined($gne->getSymbol) ) { print "  symbol=" . $gne->getSymbol . "\n"; }
+	else { print "\n"; }
 }
 my $num2 = $#geneSet + 1;
 print "number of result: " . $num2 . "\n";
